==> Files.com-1.0.766.tar.gz: Files.com-1.0.766/files_sdk/models/sync_job.py <==
import datetime
from files_sdk.api import Api
from files_sdk.list_obj import ListObj
from files_sdk.exceptions import InvalidParameterError, MissingParameterError, NotImplementedError

class SyncJob:
    default_attributes = {
        'queued_at': None,     # date-time - Job enqueued at
        'updated_at': None,     # date-time - Job updated at
        'status': None,     # string - Status of the job
        'regional_worker_status': None,     # string - Most recent reported status of sync worker
        'uuid': None,     # string -
        'folder_behavior_id': None,     # int64 -
    }

    def __init__(self, attributes=None, options=None):
        if not isinstance(attributes, dict):
            attributes = {}
        if not isinstance(options, dict):
            options = {}
        self.set_attributes(attributes)
        self.options = options

    def set_attributes(self, attributes):
        for (attribute, default_value) in SyncJob.default_attributes.items():
            setattr(self, attribute, attributes.get(attribute, default_value))

    def get_attributes(self):
        return {k: getattr(self, k, None) for k in SyncJob.default_attributes if getattr(self, k, None) is not None}


# Parameters:
#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
#   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
def list(params = None, options = None):
    if not isinstance(params, dict):
        params = {}
    if not isinstance(options, dict):
        options = {}
    if "cursor" in params and not isinstance(params["cursor"], str):
        raise InvalidParameterError("Bad parameter: cursor must be an str")
    if "per_page" in params and not isinstance(params["per_page"], int):
        raise InvalidParameterError("Bad parameter: per_page must be an int")
    return ListObj(SyncJob,"GET", "/sync_jobs", params, options)

def all(params = None, options = None):
    list(params, options)

def new(*args, **kwargs):
    return SyncJob(*args, **kwargs)

==> Files.com-1.0.841.tar.gz: Files.com-1.0.841/files_sdk/models/sync_job.py <==
import builtins
import datetime
from files_sdk.api import Api
from files_sdk.list_obj import ListObj
from files_sdk.exceptions import InvalidParameterError, MissingParameterError, NotImplementedError

class SyncJob:
    default_attributes = {
        'queued_at': None,     # date-time - Job enqueued at
        'updated_at': None,     # date-time - Job updated at
        'status': None,     # string - Status of the job
        'regional_worker_status': None,     # string - Most recent reported status of sync worker
        'uuid': None,     # string -
        'folder_behavior_id': None,     # int64 -
    }

    def __init__(self, attributes=None, options=None):
        if not isinstance(attributes, dict):
            attributes = {}
        if not isinstance(options, dict):
            options = {}
        self.set_attributes(attributes)
        self.options = options

    def set_attributes(self, attributes):
        for (attribute, default_value) in SyncJob.default_attributes.items():
            setattr(self, attribute, attributes.get(attribute, default_value))

    def get_attributes(self):
        return {k: getattr(self, k, None) for k in SyncJob.default_attributes if getattr(self, k, None) is not None}


# Parameters:
#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
#   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
def list(params = None, options = None):
    if not isinstance(params, dict):
        params = {}
    if not isinstance(options, dict):
        options = {}
    if "cursor" in params and not isinstance(params["cursor"], str):
        raise InvalidParameterError("Bad parameter: cursor must be an str")
    if "per_page" in params and not isinstance(params["per_page"], int):
        raise InvalidParameterError("Bad parameter: per_page must be an int")
    return ListObj(SyncJob,"GET", "/sync_jobs", params, options)

def all(params = None, options = None):
    list(params, options)

def new(*args, **kwargs):
    return SyncJob(*args, **kwargs)
